import { message, Space, Upload, Image } from "antd"
import { PlusOutlined, LoadingOutlined } from "@ant-design/icons";
import { RcFile } from "antd/lib/upload";
import React, { useState } from "react";
import './index.less'
import { getBase64 } from "@/utils";
import { getOssInfo } from "@/services/ant-design-pro/api";
import { request } from "@umijs/max";

interface Props {
    value?: string,  // 压缩包地址
    onChange?: (data: RcFile | string) => void,
    tooltip?: JSX.Element
}
const UploadImg: React.FC<Props> = (props) => {

    /** 变量START */
    const { value, tooltip,  onChange } = props
    const [zipFile, setZipFile] = useState<string>(value || '');
    const [loading, setLoading] = useState<boolean>(false)
    const [visible, setVisible] = useState<boolean>(false)
    /** 变量END */

    const beforeUpload = async (file: RcFile) => {
        const isJpgOrPng = file.type === 'image/jpeg' || file.type === 'image/png';
        if (!isJpgOrPng) {
            message.error('您只能上传JPG/PNG文件！');
        }
        const isLt2M = file.size / 1024 / 1024 < 2;
        if (!isLt2M) {
            message.error('图像必须小于2MB！');
        }

        return isJpgOrPng && isLt2M;
    };

    const uploadButton = (
        <div>
            {loading ? <LoadingOutlined /> : <PlusOutlined />}
            {/* <div style={{ marginTop: 8 }}>Upload</div> */}
        </div>
    );

    return <div className="myUpload">
        <Space align="start">
            <Upload
                name="avatar"
                listType="picture-card"
                accept='.zip, .rar, application/zip, application/x-rar-compressed'
                className="avatar-uploader"
                beforeUpload={beforeUpload}
                maxCount={1}
                showUploadList={false}
                customRequest={(options: any) => {
                    // setLoading(true)
                    // getOssInfo({ type: 'image/jpeg', fileType: 'image' }).then(async res => {
                    //     try {
                    //         let formData = new FormData();
                    //         Object.keys(res.data).forEach((key: string) => {
                    //             if (key !== 'url') {
                    //                 formData.append(key, res.data[key])
                    //             }
                    //         })
                    //         formData.append('file', options.file)
                    //         let urlData = await request(res?.data?.ossUrl, { method: 'POST', data: formData })
                    //         setLoading(false)
                    //         setImageFile(urlData?.data?.url);
                    //         if (urlData?.data?.url) {
                    //             onChange && onChange(urlData?.data?.url)
                    //         }
                    //     } catch (error) {
                    //         setLoading(false)
                    //     }
                    // })
                }}
            >
                {zipFile ? <Image src={zipFile} preview={false} style={{ height: '85px' }} /> : uploadButton}
            </Upload>
            <div>{tooltip && tooltip}</div>
            {/* {zipFile && <div className="look">
                <a onClick={() => setVisible(true)}>预览</a>
                <Image
                    style={{ display: 'none' }}
                    src={imageFile}
                    preview={{
                        visible,
                        src: imageFile,
                        onVisibleChange: value => {
                            setVisible(value);
                        },
                    }}
                />
            </div>} */}

        </Space>
    </div>
}


export default React.memo(UploadImg)